# - Config file for the IGNITION-FUEL-TOOLS package.
#
# For finding and loading IGNITION-FUEL-TOOLS from your project, type:
#
# find_package(ignition-fuel-tools0)
#
# It defines the following variables:
#
#  ignition-fuel-tools0_FOUND       - System has IGNITION-FUEL-TOOLS.
#  IGNITION-FUEL-TOOLS_INCLUDE_DIRS - include directories for IGNITION-FUEL-TOOLS and its dependencies.
#  IGNITION-FUEL-TOOLS_LIBRARY_DIRS - Paths in which the linker should search for libraries.
#  IGNITION-FUEL-TOOLS_LIBRARIES    - Libraries to link against.
#  IGNITION-FUEL-TOOLS_CXX_FLAGS    - Compiler flags for compiling C++ sources.
#  IGNITION-FUEL-TOOLS_LDFLAGS      - Linker flags.

include (FindPkgConfig REQUIRED)

if (IGNITION-FUEL-TOOLS_CONFIG_INCLUDED)
  return()
endif()
set(IGNITION-FUEL-TOOLS_CONFIG_INCLUDED TRUE)

list(APPEND IGNITION-FUEL-TOOLS_INCLUDE_DIRS
"/usr/include/ignition/fuel-tools0")

list(APPEND IGNITION-FUEL-TOOLS_LIBRARY_DIRS
"/usr/lib/i386-linux-gnu")

# Visual Studio enables c++11 support by default
if (NOT MSVC)
  list(APPEND IGNITION-FUEL-TOOLS_CXX_FLAGS -std=c++11)
endif()
if (${CMAKE_CXX_COMPILER_ID} MATCHES "Clang")
  set(IGNITION-FUEL-TOOLS_CXX_FLAGS "${IGNITION-FUEL-TOOLS_CXX_FLAGS} -stdlib=libc++")
endif ()

# On Windows we need to link against .lib files with no prefix.
if (WIN32)
  SET(CMAKE_FIND_LIBRARY_PREFIXES "")
  SET(CMAKE_FIND_LIBRARY_SUFFIXES ".lib")
endif()

foreach(lib ignition-fuel-tools0)
  set(onelib "${lib}-NOTFOUND")
  find_library(onelib ${lib}
    PATHS "/usr/lib/i386-linux-gnu"
    NO_DEFAULT_PATH
    )
  if(NOT onelib)
    message(FATAL_ERROR "Library '${lib}' in package IGNITION-FUEL-TOOLS is not installed properly")
  endif()
  list(APPEND IGNITION-FUEL-TOOLS_LIBRARIES ${onelib})
endforeach()

if (MSVC)
  list(APPEND IGNITION-FUEL-TOOLS_LIBRARIES Ws2_32.lib Iphlpapi.lib)
endif()

list(APPEND IGNITION-FUEL-TOOLS_LDFLAGS -L"/usr/lib/i386-linux-gnu")
